@@ -5,19 +5,23 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.assets._jsii
 import aws_cdk.aws_ecr._jsii
 import aws_cdk.aws_iam._jsii
-import aws_cdk.aws_lambda._jsii
 import aws_cdk.aws_s3._jsii
 import aws_cdk.core._jsii
 import aws_cdk.cx_api._jsii
 import constructs._jsii
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-ecr-assets", "1.44.0", __name__[0:-6], "aws-ecr-assets@1.44.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load(
+    "@aws-cdk/aws-ecr-assets",
+    "1.136.0",
+    __name__[0:-6],
+    "aws-ecr-assets@1.136.0.jsii.tgz",
+)
 
 __all__ = [
     "__jsii_assembly__",
